﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Syncfusion.Windows.Forms.Diagram;
using System.Drawing.Imaging;
using Syncfusion.Windows.Forms.Tools;
using Syncfusion.Windows.Forms.Diagram.Controls;
using System.Drawing.Drawing2D;
using Syncfusion.Windows.Forms;
using System.IO;
using System.Drawing.Printing;
using Syncfusion.SVG.IO;
using System.Collections;

namespace DifferentLayoutInEveryLevel
{
    public partial class Form1 : Form
    {
        private bool excludeBeginRootwithConnector = true;

        public Form1()
        {
            InitializeComponent();
            this.diagram2.Model.BoundaryConstraintsEnabled = true;
        }

        private void Form1_Load(object sender, EventArgs e)
        {
            NodeCollection radialnodes = new NodeCollection();
            NodeCollection directed1 = new NodeCollection();

            RadialNodes(ref radialnodes);
            RadialLayouting(radialnodes);

            DirectedLayout1Nodes(ref directed1);
            DirectedLayouting1(directed1);

            diagram2.View.SelectionList.Clear();
        }

        private void RadialNodes(ref NodeCollection nodes)
        {
            //First level node
            Ellipse e1 = new Ellipse(0, 0, 90, 90);
            e1.Name = "centerNode";
            e1.FillStyle.Color = Color.FromArgb(160, 80, 80);
            e1.FillStyle.ForeColor = Color.FromArgb(255, 45, 45);
            e1.FillStyle.Type = FillStyleType.LinearGradient;
            e1.LineStyle.LineWidth = 0;
            e1.EnableShading = false;
            nodes.Add(e1);
            diagram2.Model.Nodes.Add(e1);
            GenerateInnerLevelNodes(e1, 5, Color.FromArgb(255, 128, 64), Color.FromArgb(255, 201, 74), 0, ref nodes);
        }

        private void DirectedLayout1Nodes(ref NodeCollection nodes)
        {
            Node parentNode = diagram2.Model.Nodes.FindNodeByName("centerNode");
            excludeBeginRootwithConnector = false;
            for (var i = 0; i < 1; i++)
            {
                Ellipse e1 = GetEllipse(Color.Blue, Color.Blue);
                diagram2.Model.Nodes.Add(e1);
                nodes.Add(e1);
                ConnectNodes(parentNode, e1, Color.Red, ref nodes);

                if (i == 0)
                {
                    for (var j = 0; j < 2; j++)
                    {
                        Ellipse e2 = GetEllipse(Color.Blue, Color.Blue);
                        diagram2.Model.Nodes.Add(e2);
                        nodes.Add(e2);
                        ConnectNodes(e1, e2, Color.Red, ref nodes);
                    }
                }
            }
        }


        private void GenerateInnerLevelNodes(Node parentNode, int maxSubNodes, Color LevelColor, Color foreColor, int n, ref NodeCollection nodes)
        {
            for (int i = 0; i < 9; i++)
            {
                Ellipse ellipse1 = GetEllipse(LevelColor, foreColor);
                nodes.Add(ellipse1);
                diagram2.Model.Nodes.Add(ellipse1);
                ConnectNodes(parentNode, ellipse1, Color.Black, ref nodes);
            }
        }

        private static Ellipse GetEllipse(Color fillColor, Color foreColor)
        {
            Ellipse ellipse1 = new Ellipse(0, 0, 45, 45);
            ellipse1.FillStyle.Color = fillColor;
            ellipse1.FillStyle.ForeColor = foreColor;
            ellipse1.LineStyle.LineColor = Color.Transparent;
            ellipse1.FillStyle.Type = FillStyleType.LinearGradient;
            ellipse1.FillStyle.Type = FillStyleType.LinearGradient;
            return ellipse1;
        }

        private void ConnectNodes(Node parentNode, Node childNode, Color connectionColor, ref NodeCollection nodes)
        {
            if (parentNode != null && childNode != null)
            {
                LineConnector lConnector = new LineConnector(PointF.Empty, new PointF(0, 1));
                //lConnector.HeadDecorator.DecoratorShape = DecoratorShape.Filled45Arrow;               
                lConnector.HeadDecorator.FillStyle.Color = Color.White;
                lConnector.HeadDecorator.LineStyle.LineColor = connectionColor;
                lConnector.LineStyle.LineColor = connectionColor;


                parentNode.CentralPort.TryConnect(lConnector.TailEndPoint);
                childNode.CentralPort.TryConnect(lConnector.HeadEndPoint);
                if (excludeBeginRootwithConnector)
                    nodes.Add(lConnector);
                diagram2.Model.Nodes.Add(lConnector);
                diagram2.Model.SendToBack(lConnector);
            }
        }



        private void RadialLayouting(NodeCollection nodes)
        {
            RadialTreeLayoutManager radialLayout = new RadialTreeLayoutManager();
            radialLayout.AutoLayout = true;
            radialLayout.HorizontalSpacing = 30;
            radialLayout.VerticalSpacing = 30;
            radialLayout.Model = diagram2.Model;
            radialLayout.Nodes.Clear();
            radialLayout.Nodes.AddRange(nodes);
            this.diagram2.LayoutManager = radialLayout;
            radialLayout.UpdateLayout(radialLayout.Nodes);
        }

        private void DirectedLayouting1(NodeCollection nodes)
        {
            DirectedTreeLayoutManager directLaout = new DirectedTreeLayoutManager();
            directLaout.AutoLayout = true;
            directLaout.HorizontalSpacing = 30;
            directLaout.VerticalSpacing = 30;

            directLaout.Model = diagram2.Model;

            directLaout.Nodes.Clear();
            directLaout.Nodes.AddRange(nodes);

            this.diagram2.LayoutManager = directLaout;
            directLaout.UpdateLayout(directLaout.Nodes);
        }
    }
}